import json
import argparse
import skillsnetwork.cvstudio


def report(data, interactive):
    cvstudio = skillsnetwork.cvstudio.CVStudio(interactive=interactive)

    result = cvstudio.report(**data)

    if result.ok:
        print("Congratulations your results have been reported back to CV Studio!")
    else:
        print("Failed to report results.")
        print(result.text)


if __name__ == "__main__":
    parser = argparse.ArgumentParser(description="Send a Report to CV Studio")
    parser.add_argument(
        "-i", "--interactive", nargs="*", help="Interactive login prompt"
    )
    parser.add_argument(
        "jsonFilename",
        nargs="+",
        help="Filename(s) of JSON files containing data to send to CV Studio",
    )
    args = parser.parse_args()

    data = {}
    for filename in args.jsonFilename:
        with open(filename) as f:
            data.update(json.load(f))

    report(data, interactive=args.interactive is not None)



import json
import argparse
import skillsnetwork.cvstudio


def upload(modelFilename, data, interactive):
    cvstudio = skillsnetwork.cvstudio.CVStudio(interactive=interactive)

    result = cvstudio.upload(**data)

    if result.ok:
        print("Congratulations your results have been reported back to CV Studio!")
    else:
        print("Failed to report results.")
        print(result.text)


if __name__ == "__main__":
    parser = argparse.ArgumentParser(description="Upload a Model to CV Studio")
    parser.add_argument(
        "-c",
        "--configFilename",
        help="Optional Filename of JSON files containing data to send to CV Studio",
    )
    parser.add_argument(
        "-i", "--interactive", nargs="*", help="Interactive login prompt"
    )
    parser.add_argument(
        "modelFilename",
        help="Filename of model file (e.g. model.pt) to send to CV Studio",
    )
    args = parser.parse_args()

    if args.configFilename:
        with open(args.configFilename) as f:
            data = json.load(f)

        upload(args.modelFilename, data, interactive=args.interactive is not None)
    else:
        upload(args.modelFilename, {}, interactive=args.interactive is not None)



import json
import argparse
import skillsnetwork.cvstudio


def ping(interactive):
    cvstudio = skillsnetwork.cvstudio.CVStudio(interactive=interactive)

    result = cvstudio.ping()

    if result.ok:
        print("Congratulations you are connected to CV Studio!")
        item = json.loads(result.text)
        if "trainingrun" in item:
            print("Training Run: " + item["trainingrun"]["name"])
        elif "app" in item:
            print("Application: " + item["app"]["name"])
    else:
        print("Failed to contact CV Studio.")
        print(result.text)


if __name__ == "__main__":
    parser = argparse.ArgumentParser(description="Ping CV Studio")
    parser.add_argument(
        "-i", "--interactive", nargs="*", help="Interactive login prompt"
    )
    args = parser.parse_args()

    ping(interactive=args.interactive is not None)



import argparse
import skillsnetwork.cvstudio


def setup(interactive):
    cvstudio = skillsnetwork.cvstudio.CVStudio(interactive=interactive)

    cvstudio.download_all()


if __name__ == "__main__":

    parser = argparse.ArgumentParser(
        description="Download all images from CV Studio project."
    )
    parser.add_argument(
        "-i", "--interactive", nargs="*", help="Interactive login prompt"
    )
    args = parser.parse_args()

    setup(interactive=args.interactive is not None)
